"""
# File       : __init__.py.py
# Time       ：2024/8/22 09:33
# Author     ：xuewei zhang
# Email      ：shuiheyangguang@gmail.com
# version    ：python 3.12
# Description：
"""
from .api_服务器配置验证 import router as server_router
